# -*- coding: utf-8 -*-
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

extensions = ['openstackdocstheme']

source_suffix = '.rst'

master_doc = 'index'

project = u'tripleo-ui'
copyright = u'2017, OpenStack Foundation'

pygments_style = 'sphinx'

htmlhelp_basename = '%sdoc' % project
html_theme = 'openstackdocs'

repository_name = 'openstack/tripleo-ui'
bug_project = 'tripleo'
bug_tag = 'ui'
